<?php

/**
 * Class that represents profiler output to ZRay
 *
 * Copyright (c) 2023 Zend by Perforce
 */

namespace Magento\Framework\Profiler\Driver\Standard\Output;

use Magento\Framework\Profiler;
use Magento\Framework\Profiler\Driver\Standard\AbstractOutput;
use Magento\Framework\Profiler\Driver\Standard\Stat;

class Zray extends AbstractOutput
{
    /**
     * @var array Profiler data collection
     */
    public array $zrayData = [];

    /**
     * Collect profiling results
     */
    public function display(Stat $stat): void
    {
        $this->zrayData = [];
        foreach ($this->_getTimerIds($stat) as $timerId) {
            $names = explode(Profiler::NESTING_SEPARATOR, $timerId);
            $id = array_pop($names);
            $count = count($names);
            $tabs = $count ? str_repeat('  ', count($names)) . '⋯ ' : '';
            $this->zrayData[] = [
                'Timer id' => $tabs . $id,
                'Time (ms)' =>  number_format(1000 * $stat->fetch($timerId, 'sum'), 3),
                'Average (ms)' => number_format(1000 * $stat->fetch($timerId, 'avg'), 3),
                'Count' => $stat->fetch($timerId, 'count'),
                'Emalloc' => number_format($stat->fetch($timerId, 'emalloc')),
                'RealMem' => number_format($stat->fetch($timerId, 'realmem'))
            ];
        }
    }
}
